@@ -16,7 +16,7 @@ class EqualizerWidget;
 
 class EqualizerLevel : public TQWidget
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	EqualizerLevel(TQWidget *parent, VBand band);
@@ -36,7 +36,7 @@ private:
 
 class PresetList : public TDEListView
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	PresetList(TQWidget *parent, const char *name=0);
@@ -48,7 +48,7 @@ public:
 
 class EqualizerView : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 	TQPtrList<EqualizerLevel> mBands;
 
